@@ -8,6 +8,7 @@
 #include <quic/common/test/TestUtils.h>
 
 #include <fizz/crypto/test/TestUtil.h>
+#include <fizz/protocol/OpenSSLSelfCertImpl.h>
 #include <fizz/protocol/clock/test/Mocks.h>
 #include <fizz/protocol/test/Mocks.h>
 #include <quic/api/QuicTransportFunctions.h>
@@ -115,7 +116,7 @@ static std::shared_ptr<fizz::SelfCert> readCert() {
   auto privKey = fizz::test::getPrivateKey(fizz::test::kP256Key);
   std::vector<folly::ssl::X509UniquePtr> certs;
   certs.emplace_back(std::move(certificate));
-  return std::make_shared<fizz::SelfCertImpl<fizz::KeyType::P256>>(
+  return std::make_shared<fizz::OpenSSLSelfCertImpl<fizz::KeyType::P256>>(
       std::move(privKey), std::move(certs));
 }
 
