@@ -216,19 +216,6 @@ class QuicServer : public QuicServerWorker::WorkerCallback,
    */
   void waitUntilInitialized();
 
-  void handleWorkerError(LocalErrorCode error) override;
-
-  /**
-   * Routes the given data for the given client to the correct worker that may
-   * have the state for the connection associated with the given data and client
-   */
-  void routeDataToWorker(
-      const folly::SocketAddress& client,
-      RoutingData&& routingData,
-      NetworkData&& networkData,
-      folly::Optional<QuicVersion> quicVersion,
-      bool isForwardedData = false) override;
-
   /**
    * Set the transport factory for the worker associated with the given
    * eventbase.
@@ -365,6 +352,29 @@ class QuicServer : public QuicServerWorker::WorkerCallback,
  private:
   QuicServer();
 
+  /**
+   * Routes the given data for the given client to the correct worker that may
+   * have the state for the connection associated with the given data and client
+   */
+  void routeDataToWorker(
+      const folly::SocketAddress& client,
+      RoutingData&& routingData,
+      NetworkData&& networkData,
+      folly::Optional<QuicVersion> quicVersion,
+      folly::EventBase* workerEvb,
+      bool isForwardedData = false) override;
+
+  void handleWorkerError(LocalErrorCode error) override;
+
+  using MaybeOwnedEvbPtr =
+      std::unique_ptr<folly::IOExecutor, void (*)(folly::IOExecutor*)>;
+
+  // initializes a QuicServerWorker per evb.
+  void initializeImpl(
+      const folly::SocketAddress& address,
+      std::vector<MaybeOwnedEvbPtr> evbs,
+      bool useDefaultTransport = false);
+
   struct EventBaseBackendDetails {
     std::unique_ptr<folly::EventBaseBackendBase> (*factory)();
     bool supportsRecvmsgMultishot = false;
@@ -372,9 +382,7 @@ class QuicServer : public QuicServerWorker::WorkerCallback,
   static EventBaseBackendDetails getEventBaseBackendDetails();
 
   // helper function to initialize workers
-  void initializeWorkers(
-      const std::vector<folly::EventBase*>& evbs,
-      bool useDefaultTransport);
+  void initializeWorkers(bool useDefaultTransport);
 
   std::unique_ptr<QuicServerWorker> newWorkerWithoutSocket();
 
@@ -384,9 +392,7 @@ class QuicServer : public QuicServerWorker::WorkerCallback,
   // helper method to run the given function in all worker synchronously
   void runOnAllWorkersSync(const std::function<void(QuicServerWorker*)>& func);
 
-  void bindWorkersToSocket(
-      const folly::SocketAddress& address,
-      const std::vector<folly::EventBase*>& evbs);
+  void bindWorkersToSocket(const folly::SocketAddress& address);
 
   std::vector<QuicVersion> supportedVersions_{{
       QuicVersion::MVFST,
@@ -404,7 +410,10 @@ class QuicServer : public QuicServerWorker::WorkerCallback,
   std::mutex startMutex_;
   std::atomic<bool> initialized_{false};
   std::atomic<bool> takeoverHandlerInitialized_{false};
-  std::vector<std::unique_ptr<folly::ScopedEventBaseThread>> workerEvbs_;
+
+  // stores all the worker evbs which may be owned (i.e. ScopedEventBaseThread)
+  // or unowned (i.e. folly::EventBase*)
+  folly::Synchronized<std::vector<MaybeOwnedEvbPtr>> workerEvbs_;
 
   std::vector<std::unique_ptr<QuicServerWorker>> workers_;
   // Thread local pointer to QuicServerWorker. This is useful to avoid
