@@ -180,7 +180,7 @@ void QuicServerWorker::setUnfinishedHandshakeLimit(
 void QuicServerWorker::start() {
   CHECK(socket_);
   if (!pacingTimer_) {
-    pacingTimer_ = std::make_unique<TimerFDQuicTimer>(
+    pacingTimer_ = std::make_unique<HighResQuicTimer>(
         evb_.get(), transportSettings_.pacingTimerResolution);
   }
   socket_->resumeRead(this);
@@ -614,11 +614,12 @@ void QuicServerWorker::forwardNetworkData(
       std::move(routingData),
       std::move(networkData),
       std::move(quicVersion),
+      getEventBase(),
       isForwardedData);
 }
 
 void QuicServerWorker::setPacingTimer(
-    TimerFDQuicTimer::SharedPtr pacingTimer) noexcept {
+    QuicTimer::SharedPtr pacingTimer) noexcept {
   pacingTimer_ = std::move(pacingTimer);
 }
 
@@ -1291,7 +1292,6 @@ void QuicServerWorker::onConnectionIdAvailable(
       // If we aren't currently running, start the timer.
       evb_->timer().scheduleTimeout(this, timeLoggingSamplingInterval_);
     }
-    QUIC_STATS(statsCallback_, onNewConnection);
   }
 }
 
